"""CoreConsultingWings URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path

from djangoDeployGitHook import views

urlpatterns = [
    path('test_githook', views.test_githook, name='test_githook'),
    path('githookA2HostingClone', views.githookA2HostingCloneUpdate, name='githookA2HostingClone'),
    path('githookA2HostingRemote', views.githookA2HostingRemoteUpdate, name='githookA2HostingRemote'),
    path('githookRaspberry', views.githookRaspberry, name='githookRaspberry'),

    path('test_update', views.test_update, name='test_update'),
]
